@@ -201,7 +201,7 @@ class Toilmore(object):
         if not adjustments:
             return {}
         try:
-            schema = self.get_schema_contents('adjustments_schema.json')
+            schema = self.get_schema_contents('adjuster-schema.json')
             jsonschema.validate(adjustments, schema=schema)
             return adjustments
         except jsonschema.exceptions.ValidationError as err:
